# SoftM Suite Tabellennamen #

Dies ist eine Liste der uns bekannten Tabellen in dem ERP-System "SoftM Suite" und deren Status in unserer Installation. Einzelne Feldnamen sind in  [fields.py][fields] dokumentiert. Das Python Paket [HuSoftm][HuSoftm] erlaubt den Zugriff auf diese Felder.

[fields]:  http://github.com/hudora/huSoftM/blob/master/husoftm/fields.py
[HuSoftm]: http://github.com/hudora/huSoftM/

## Auftragsbearbeitung ##

    AAE00 	Auftragseingangsstatistik
    AAK00 	Auftragskopfdaten
    AAN00 	Auftrags-Nummern-Datei
    AAP00 	Auftragspositionen
    AAT00 	Auftrags-Texte
    AAY00 	Artikel-Statistikdatei
    ABA00 	Stapelschnittstelle Auftrag:
    ABB00 	ABB00: Vergleichsdatei für B
    ABK00 	Stapelschnittstelle Auftrag:
    ABS00 	BBS-Datei/SEDAS (für AFA43)
    ABT00 	Stapelschnittstelle (Textda
    ABV00 	Stapelschnittstelle (Adress
    ADD00 	DSD-Verpackungsdaten
    ADG00 	DSD-Gebühren
    ADP00 	DPD-Routendaten
    ADS00 	DSD - Verpackungsangaben
    ADV00 	Steuerung Versandaufkleber
    ADW00 	DSD - Statistikdatei
    AEP00 	Emballagen-Bewegungs-Datei/n
    AES00 	Zuordnung Serien-Nummer zu K
    AEX00 	SSt Exportpapiere Kopfdaten
    AEY00 	SSt Exportpapiere Positionsd
    AF100 	C/S FaktAw?: Arbeitsdatei für
    AF200 	C/S FaktAw?: Arbeitsdatei für
    AFE00 	Vorgänge für EDI-Schnittstelle
    AFK00 	Rechnungsköpfe
    AFL00 	Rechnungslisten
    AFM00 	Mehrwertsteuerangaben pro Re
    AFP00 	Fakturierte Set-Komponenten
    AFR00 	Fakturierungs-Positions-Raba
    AFS00 	Rechnungszusatzdaten / SEDAS
    AFT00 	Fakturierung: Texte und Seri
    AFU00 	Rechnungspositionen
    AFV00 	Rechnungs-Positions-Zusatzda
    AFX00 	Fakturierungs-Text-Datei
    AGA00 	Garantie-Datei
    AGE00 	German Parcel (GPPLZEPL.PRN)
    AGK00 	Erlöskonten
    AGM00 	Mengen-Statistiksummendatei
    AGP00 	German Parcel
    AGS00 	Planzahlen-Statistiksummenda
    AGU00 	Tariftabelle für UPS-Versand
    AGY00 	Statistiksummendatei mit var
    AHY00 	Kunden-Hierarchie-Summendate
    AJA00 	Journal-Daten für SoftM Wied
    AKA00 	Kunden-Artikel-Datei
    AKE00 	Kommerzielle Entscheidungsfä
    AKH00 	Kunden-Hierarchie-Datei
    AKK00 	SSt Auftrag/KoRe: Kontenzuor
    AKM00 	Kunden-Artikel-Umsätze je Mo
    AKO00 	Set-Komponenten-Datei
    AKT00 	Kunden-Artikel-Texte
    AKY00 	Kunden-Statistik-Datei
    AKZ00 	Kunden-Zusatzdatei
    ALD00 	KB/LS : Adressdatei
    ALG00 	LoGo? Lieferservice Leitzahle
    ALH00 	Leihdatei
    ALK00 	Lieferscheinkopfdaten
    ALL00 	Abgleichdatei Lager / Leihda
    ALN00 	Lieferscheinpositionen
    ALU00 	Lieferumfang Kopf (Sonderfäl
    ALV00 	Lieferumfang Positionen (Son
    ALX00 	Lieferschein-Textdatei
    AMK00 	Metall-Tageskurse
    AOD00 	Angebote: Einmal-Adress-Date
    AOH00 	Angebots-Kopfdaten
    AOI00 	Angebots-Informationen
    AOK00 	Angebotskopfdaten - je Kunde
    AOP00 	Angebotspositonen
    AOR00 	Angebotsreferenzen
    AOT00 	Angebots-Texte
    AP100 	Temporäre Pooldatei -> Ges.
    AP200 	Temporäre Pooldatei -> Kommi
    AP300 	Temporäre Pooldatei -> KOmm.
    APC00 	EDIFACT: PRICAT-Datei
    APD00 	APD00: Programm-Protokoll-Da
    APK00 	Palettenkopfdaten
    APL00 	Anrufplan
    APN00 	Palettenpositionsdaten
    APR00 	Preisdatei
    APV00 	Vorgangsbezogene Konditionen
    APZ00 	Preisdatei-Zugriffsdatei
    AR100 	C/S Retouren: Kopfdatei
    AR200 	C/S Retouren: Positionsdatei
    AR300 	C/S Retouren: Kopfdatei
    AR400 	C/S Retouren: Positionsdatei
    ARA00 	Zwischendatei Positionsdaten
    ARF00 	Retouren-Ersatzlieferungen
    ARG00 	Angaben zur Reorganisation e
    ARH00 	Retouren-Kopfdatei
    ARK00 	Zwischendatei Kopfdaten für
    ARL00 	Retouren-Rücklieferungen
    ARP00 	Retouren-Positionsdatei
    ARS00 	Retouren-Gutschriften
    ART00 	Retouren: Textdatei für Ersa
    ARU00 	Retouren-Umbuchungen
    ARZ00 	Retouren-Warenvereinnahmunge
    ASD00 	SEDAS-Rechnungsdaten-Datei
    ASK00 	Set-Komponenten-Datei
    ASP00 	SEDAS: Parameter pro Firma u
    AST00 	Einzelstatistikdatei
    ASV00 	Sollvorgaben / Summenstatist
    ASX00 	Sollvorgaben / Summenstatist
    ASZ00 	Planwerte ArtG - Zusatzdatei
    ATF00 	Versand Tarifcodes
    ATG00 	Tourenfahrten
    ATL00 	Schnittstelle Trans-O-Flex
    ATM00 	Tourenfahrten Rückmeldedaten
    ATO00 	Trans-O-Flex (TOF.LE)
    ATP00 	Pausenzeiten
    ATR00 	Touren-Angaben
    ATS00 	Tourenstamm
    ATT00 	Liefertage und -tour
    ATU00 	Rückfrachten
    ATY00 	Tagesstatistikdatei
    ATZ00 	Tourenzuordnung
    AUP00 	Protokoll-Datei Kunden-Zuord
    AV100 	Hilfsdatei Vertreter-Provisi
    AVA00 	Versandadressdatei
    AVC00 	Versandabwicklung: Chargen-/
    AVF00 	Parameter Versandabwicklung
    AVH00 	Bonus-Summen-Datei
    AVK00 	Bonus-Kunden-Zuordnungsdatei
    AVL00 	Versanddatei LO-GO Lieferser
    AVM00 	Vertreter-Provisions-Summend
    AVN00 	Versandabwicklung: Leitdaten
    AVO00 	Bonus-Vorschlagsdatei
    AVP00 	Vertreterprovisionsdatei
    AVQ00 	Hilfsdatei zur Erstellung de
    AVR00 	Schnittstellendatei für Heid
    AVS00 	Versand-/Speditionsdaten
    AVX00 	Versandabwicklung: Paketposi
    AVY00 	Zuordnungsdatei Bonusvorschl
    AVZ00 	Versandabwicklung: Paketkopf
    AYA00 	Monatl. Abrechnung pro Servi
    AYC00 	CHEP-Transferdatei
    AYE00 	Entsorgungskostenstatistik-D
    AYF00 	Frachtkosten-Datei
    AYG00 	Zwischendatei für Frachtstat
    AYJ00 	Jahresstatistik pro Servicek
    AYK00 	Kundenzusatz / Lebensmittelh
    AYR00 	Einzelaufträge pro Streckenr
    AYS00 	Service-Kräfte Stammdaten
    AYZ00 	Kundennummern pro Servicekra
    AZU00 	Artikel-Zuschlagsdatei

## Buchhaltung ##

    BA100 	Adressen Einmalkunden/-Lieferanten
    BAD00 	Adressen Einmalkunden/-Lieferanten - Rechnungsadressen?
    BAG00 	Abteilungsgruppen-Kopfdatei
    BAK00 	7.00 Abstimmkreise
    BAP00 	Abteilungsgruppen/Postitions
    BBB00 	Stapelschnittstelle der Buch
    BBE00 	Bankangaben Einmalkunden/lie
    BBF00 	Fehlerhafte Stapelbuchungen
    BBK00 	Warenkreditversicherung work
    BBN00 	Banken-Informationen Kred./D
    BBP00 	Zusatz periodische Buchungen
    BBT00 	Datei Buchungen für besonder
    BBU00 	BBU: Buchungen
    BBW00 	WKV Zusatz zur BBU/BOP
    BBZ00 	7.00 Buchungen Zusatz Koste
    BCA00 	ZH: I/A/L/S/V: ZV ausgewählt
    BCB00 	ZH: I: Hilfsdatei für Betrag
    BCI00 	ZH: I/A/L/S/V: ZV ausgewählt
    BCL00 	ZH: I/A/L/S/V: ZV ausgewählt
    BCS00 	ZH: I/A/L/S/V: ZV ausgewählt
    BCV00 	ZH: I/A/L/S/V: ZV ausgewählt
    BCX00 	ZH: I/A/L/S/V: ZV-Kontroll-D
    BCY00 	Kopie von BCZ00 für Client
    BCZ00 	ZH: I/A/L/S/V: ausgewählte O
    BDA00 	ZH: I/L/S/V: Inland Vorlaufs
    BDC00 	ZH: I/L/S/V: Inland Datensat
    BDE00 	ZH: I/L/S/V: Inland Endesatz
    BDM00 	ZH: A: Datenträgerdatei Ausl
    BDN00 	ZH: I/L/S/V: Datenträgerdate
    BDR00 	ZH: A: Anfangssatz 'R' Ausla
    BDS00 	ZH: I/A/L/S/V: Summen pro Ko
    BDT00 	ZH: A: Datensatz 'T' Ausland
    BDU00 	ZH: A: Meldesatz 'U' Ausland
    BDV00 	ZH: A: Meldesatz 'V' Ausland
    BDW00 	ZH: A: Meldesatz 'W' Ausland
    BDZ00 	ZH: A: Datensatz 'Z' Ausland
    BEB00 	7.00 Externe Buchungsschlüss
    BEC00 	7.00 Berechtigung Buchhaltu
    BED00 	ZM ZM-Datei
    BWU00 	WKV Umsatzkennzeichen
    BWZ00 	7.00 Wechsel: Zwischendat f
    BX100 	SoftM Suite: Adressdatei Deb
    BX200 	SoftM Suite: Adressdatei Kre
    BX300 	SoftM Suite: Stammdaten für
    BX400 	SoftM Suite: Stammdaten für
    BX500 	SoftM Suite: Stammdaten für
    BX600 	SoftM Suite: Stammdaten für
    BZB00 	ZV: Zahlbank des Kunden/Lief
    BZD00 	ZV-Statistik: Temp.Datei für
    BZE00 	ZV-Statistik: Temp. Datei Kr
    BZF00 	7.10 Firmenzusatztexte für
    BZJ00 	ZV-Statistik: Temp.Datei für

## C - Service ##

    CVT00 	Service : Textdatei für Vert
    CZV00 	Reparatur-Zubehör-Datei

## D - ??? ##

    D0000000 	SEDAS-Rechnungsdaten-Datei
    DAI00 	Paisy: DAI60SB mit Firma KEY

## E - Einkauf ##

    EAD00 	Einmal-Adress-Datei für Anwe
    EAL00 	EAL00: Artikel-Lieferanten-R
    EAM00 	EAM00: Anfragen/Musterprüfun
    EAN00 	EAN00: Artikel-Lieferanten-R
    EAP00 	EAP00: Artikel-Lief.-Preis-D
    EAS00 	EAS00: Preisdatei zur EAL00
    EAV00 	Abnahmeverpflichtung auf Art
    EAW00 	EAW00: Abweichungen in der R
    EAX00 	EAX00: Artikeltextdatei für
    EBA00 	SS-EK: Bedarfsmeldungen ( Zu
    EBB00 	Stapelschnittstelle der Buch
    EBD00 	Aufbereitete Bestellung
    EBE00 	Bankverbindungen Einmal-Lief
    EBI00 	EBI00: Bestelländerungsproto
    EBL00 	EBL00: Bestell-Kopf-Datei
    EBN00 	EBN00: Bestell-Positions-Rab
    EBP00 	EBP00: Bestell-Positions-Dat
    EBT00 	EBT00: Bestell-Text-Datei
    EBZ00 	Zusatz zu Bestelpositionsdat
    ECB00 	ECB00: Bedarfsmeldung Bedarf
    ECH00 	ECH00: Bedarfsmeldung Genehm
    ECZ00 	ECZ00: Bedarfsmeldung Zusatz
    EDI00 	EDI00: Dispositionsdatei
    EDJ00 	Verbrauchsdaten für die Disp
    EDV00 	Definition Vergangenheitshor
    EDX00 	EDX00 - Dispositionszusatzda
    EDY00 	Dispodaten auf ArtG-Basis
    EEB00 	EEB00: Rechnungskopf-Zusatzd
    EER00 	Duplikat: EER00: Lieferante
    EFP00 	Terminfortschrittsdatei - Po
    EH100 	EH100: Hilfsdatei 1 für Prei
    EJD00 	Aufsummierter Bedarf / Statistik
    EKB00 	Bonus-Kunden-Zuordnungsdatei
    EKO00 	Preisdatei
    EKS00 	EKS00: ORG-Splitting für Ein
    ELA00 	Liefernten-Ansprechpartner-D
    ELN00 	ELN00: Lieferantenpreisänder
    ELP00 	ELP00: Lieferanten-Preisände
    ELT00 	ELT00: Artikel-Lieferanten-T
    ELZ00 	ELZ00: Lieferanten-Zusatzdatei
    EMS00 	EMS00: Protokolldatei - Lief
    ENL00 	ENL00: Anfragen / Kopf-Daten
    ENP00 	ENP00: Anfrage / Positions-D
    ENT00 	ENT00: Anfragen-Text-Datei
    EPD00 	Programmprotokolldatei EINKA
    EPK00 	EPK00: Steuerung der Preisän
    EPR00 	Protokoll umgesetzter Rechnu
    EPS00 	EPS00: Stammdatei Informatio
    EQ100 	CS: Arbeitsdatei für Schlech
    EQH00 	LiefBew?./Auswertung Detail
    EQU00 	EQU00: Fehler-Codes der Qual
    EQW00 	Lieferantenbewertungsdatei
    EQX00 	Bewegungsdaten Skip-Lot-Verf
    ER100 	Arbeitsdatei Warten ORG-Spli
    ER200 	CS Arbeitsdatei Rechnungsprü
    ER300 	CS-Rechnungsprüfung Kopfdate
    ER400 	EWZ00: Arbeitsdatei
    ERL00 	ERL00: Rücklauf aus Anfragen
    ERM00 	ERM00: Anfragen/Mustereingan
    ERP00 	ERP00: Rücklauf Anfragen / P
    ERZ00 	Zusatzinfo zu ERP00
    ESA00 	Angang zu Datei ESL00: Stape
    ESB00 	'Sachbearbeiter:Zusatz für U
    ESL00 	Lager-Stapel-Schnittstelle
    ESM00 	ESM00: Verwaltung der Schlec
    ESP00 	ESP00: Zuordnung der Kostenk
    ESR00 	ESR00: Erzeugen Rechnungskop
    ESS00 	Tägliche Statistiksummen Ein
    ESW00 	ESW00: Warenzugang/Rechnungs
    ESX00 	Dispo: je ArtG Einkaufsbudge
    ETP00 	ETP00: Textdatei für Prüfvor
    ETS00 	ETS00: Tägliche Statistik-Su
    ETX00 	ETX00: Schnittstelle zu TELE
    ETY00 	ETY00: Workdatei TELEFAX-Sch
    EUS00 	Umsatz wert- und mengenmäÃŸig
    EV100 	Protokolldatei Stapelübernah
    EVA00 	Stapelschnittstelle EINKAUF:
    EVH00 	Bonus-Summen-Datei
    EVK00 	Stapelschnittstelle EINKAUF:
    EVL00 	EVL00: Bestellvorschlagsleit
    EVN00 	Stapelschnittstelle EINKAUF:
    EVO00 	Bonus-Vorschlagsdatei
    EVP00 	EVP00: Positionsdaten Einkau
    EVS00 	Sperre für Herkuntfsnummer i
    EVT00 	EVT00: Bestellvorschlagstext
    EVY00 	Zuordnungsdatei Bonusvorschl
    EW100 	CS: Arbeitsdatei Warenzugäng
    EWB00 	Verlängerte Werkbank - Prüfd
    EWE00 	EWE00: Hilfsdatei für Sortie
    EWN00 	EWN00: NK / Rabatte der Ware
    EWV00 	EWV00: Warenvereinnahmungen
    EXP00 	SS-Datei EK
    EYR00 	VESR-Schnittst. aus RG-Prüfu
    EZS00 	Zusatz zu Teilstornosatz in
    EZT00 	EZT00: Zusatz - Texte Einkau

## F - Produktion ##

    FAG00 	Arbeitsplanpositionen
    FAK00 	Arbeitsplan: Kopf
    FAL00 	Arbeitsplatz: Stammdatei
    FAM00 	Rückmeldungen Arbeitsgänge
    FAO00 	Zuordnungsdatei Betriebsmitt
    FAS00 	Sequenzdatei Arbeitsgänge &
    FAW00 	Generierungskapazitätskonto
    FAX00 	Kapazitätskonto
    FEA00 	Ersatzarbeitsplatz
    FFG00 	Fertigungsauftrag: Arbeitsgä
    FFP00 	Auftrags-Stückliste
    FSL00 	Lager-Stapel-Schnittstelle
    FSZ00 	Zuordnung Serien-Nummer zu K
    FTB00 	Zuordnung Nummer -> Zu-,Abga
    FTE00 	Exportdaten MES-Schnittstell
    FTF00 	Texte Fertigung
    FTI00 	Importdaten MES-Schnittstell
    FTM00 	Formeln: Felddefinitionen
    FTS00 	Formeln: Sequenz
    FTW00 	Tabelle für Ergebnis technis
    FUM00 	Dateien für Umstellung von W
    FUZ00 	Übergangszeiten

## G - ??? ##

    GIR00 	Referenzdatei Auftrags- / Vo
    GSG00 	Segmente
    GZK00 	Zusatzdatei Kunde

## I - Individualprogrammierung ##

    IAR00 	HUD Artikelstamm Übernahme -
    IAX00 	HUD Artikelteste Übernahme -
    IDU00 	OP Übernahme - Arbeitsdatei
    IET00 	HUD: Etikettendruckdatei für
    IFO00 	Auswahl Formularvorlagen für
    IKD00 	Kundenstamm übernehmen - Arb
    IKE00 	Kunden von extern übernehmen
    IKN00 	Kundenstamm ergänzen - Arb
    IKS00 	Kundenstamm übernehmen - Arb

## K - Kostenrechnung ##

    KAK00 	Definitionen f}r Abstimmung
    KBB00 	Schnittstelle Kostenrechnung
    KBC00 	Berechtigung Kostenrechnung
    KBF00 	Fehlerauffangdatei
    KBI00 	Monatswerte FNR,ORG,KOA,KKL
    KBP00 	Buchungsprotokoll
    KDA00 	Datenarten
    KDB00 	Bebuchbarkeit Arbeitsgebiete
    KDN00 	Nummerndatei f}r DKS-!bernah
    KDX00 	DKS-Schnitstelle: Parameter
    KFV00 	indiv. Aufteilung fix/var. K
    KGK00 	Paisy: Format KBB00 um Sortf
    KHD00 	Hierarchiedefinitionen f}r A
    KHI00 	Hierarchie nach Ebene 01
    KHN00 	Nicht zugeordnete OrgEh?
    KHR00 	Hierarchiezuordnung
    KKA00 	Kostenarten
    KKD00 	Dialogerfassung
    KKE00 	Einzelbeweg. Kostenrechnung
    KRP00 	Definitionen 'Werte aus Repo
    KSB00 	Berechtigung Sachbearbeiter
    KSD00 	Stammdatendefinitionen f}r A

## L - Lager ##

_Siehe auf jeden Fall auch XLB00 und XLF00._

    LHL00 	Lager-Stapel-Schnittstelle
    LIL00 	Lager-Stapel-Schnittstelle
    LIN00 	Inventur: Positionen einer Iventur
    LIK00 	Inventur: Leit-Daten einer Inventur
    LLG00 	Lager-Stamm-Datei (erweitert)
    LLP00 	Lagerplätze als Information
    LSS00 	Schnittstelle Umsatzstatistik - wird scheinbar ncihtmehr befüllt
    LSU00 	Umschlagsdatei für einen Artikel - beinhaltet historische Lagerbestände
    LAW00 	Lager-Stapel-Schnittstelle (leer)
    LBB00 	Stapelschnittstelle der Buchhaltung (leer)
    LBK00 	SS/FIBU: Zulässige Konto-Ken (leer)
    LBS00 	SS/FIBU: FIBU-Daten einer La (leer)
    LBX00 	Zusatz-Infos zur XLB00 (leer)
    LCH01 	XLB00: FNR / ARTN / SENR / L (leer)
    LEK00 	Verbrauchsermittlung durch Z (leer)
    LEP00 	Statistik: Einstands-Preise (leer)
    LEZ00 	Verbrauchsermittlung durch Z... (leer)
    LFF00 	Fehler-Datei der Stapelverbu (leer)
    LHS00 	Hilfsdatei für Rangfolgen au (leer)
    LIA00 	Abwertungsprozentsätze für p (leer)
    LIB00 	InvB: Inventurbewertungsdate (leer)
    LIC00 	Temporäre Chargendatei zu (leer)
    LIG00 	Inventurarbeitsdatei auf Geb (leer)
    LIP00 	InvB: Steuerung der Inventur (leer)
    LIR00 	Permanente Inventur: Statist (leer)
    LIS00 	Permanente Inventur: Statist (leer)
    LIX00 	Inventurstammdatei (leer)
    LIZ00 	INV_Platz: Inventurzusatzdat (leer)
    LKA00 	Zuordnungsdatei: Lagerkanal (leer)
    LKB00 	Schnittstelle Lager/Kosten-Rechnung (leer)
    LKO00 	Maschinelle Lagerkorrekturen (leer)
    LLB00 	SoftM Suite : Lagerbewegungen (leer)
    LLK00 	Hochregal: Lagerplatzketten (leer)
    LLQ00 	Query-File zur Sortierung we (leer)
    LMM00 	Festlegen der Monatsdauer für ... (leer)
    LMS00 	Statistik: Monatliche Statis (leer)
    LPE00 	Protokolldatei für Ermittlun (leer)
    LPK00 	Änderung des Verrechnungsprese (leer)
    LPL00 	Hochregal: Lagerplätze (leer)
    LPR00 	¢nderung des Verrechnungspre (leer)
    LSP00 	Schnittstelle FIBU: Hinterle (leer)
    LTC00 	Tempor{re Chargendatei für B (leer)
    LVA00 	Versandadressen-Stammdatei (leer)
    LVB00 	Bestand Verpackungsbehälter (leer)
    LVK00 	Versandpapiere / Kopfdaten (leer)
    LVL00 	Lager-Stapel-Schnittstelle (leer)
    LVT00 	Versandpapier-Texte (leer)

## Mehrplatzlager ##

    MBD00 	6101 Bestandsabweichungen
    MBR00 	Lagerberechtigung
    MDR00 	Daten der Dreheranalyse
    MEB00 	Passende Menge in Behälter
    MGA00 	Hilfsdatei für Differenzlist
    MHA00 	Steuerung Herkunftsarten
    MHB00 	Lagerbatcheingang
    MIP00 	Inventurpositionen
    MIU00 	6100 Inventur-Übersicht
    MIV00 	6601 Inventurleitdaten
    MLK00 	6100 Lagerplatzketten
    MLP00 	6100 Lagerplatz-Datei
    MLV00 	6100 Vorgangsdatei
    MLZ00 	Lagerplatz-Zusatzdatei
    MMP00 	6100 Prozentsätze für KZVA
    MPA00 	6100 Bestandsführung Lagerpl
    MRL00 	6100 Laufroute
    MRV00 	6500 Vorgangsrückmeldung
    MSQ00 	6500 Sektions-Stammdatei
    MVD00 	6100 Vorgangsadressen
    MVL00 	1503 Selektion Druck Vorgang
    MVN00 	6100 Inventur: Ausgewählte P
    MVT00 	6100 Vorgangstexte
    MVZ00 	6100 Sachbearbeiter/Datum/Ze

## N - ??? ##

    NAD00 	Anlagen-Stamm temporär/Liste
    NAS00 	Anlagenstammdatei

## P - ??? ##

    PSC00 	Ã„nderungstext für ausgeliefe
    PSN00 	Software-Meldungen
    PSY00 	E-Mail Datei
    PXR00 	XREF für RPG-Programme

## R - ??? ##

    RRA00 	Tuning Kostenarten
    RRB00 	Berechtigungen
    RRD00 	Jobdefinitionen
    RRE00 	Verarbeitungsläufe

## U - ??? ##

    UCJ00 	C/S Menüdatei
    UCS00 	Protokoll Send/Receive
    UCU00 	Protokoll Jobs und Current U
    UDE00 	Definitionen DataExplorer?
    UIA00 	Prompter/ UIL05FA Ersatzdate
    UIB00 	Prompter / Druckerzuordnung
    UID00 	Prompter/ UIL05FA Ersatzdate
    UIK00 	Prompter / Kopfdaten
    UIP00 	Prompter / Positionsdaten
    UIS00 	Prompter/ Feste Standardvorb
    UIV00 	Prompter / Vorbelegungen
    UIW00 	Prompter/ Werte zu Standardv
    UMC00 	C/S Menüdatei
    UND00 	SoftM-Nachrichten - ACHTUNG:
    UNP00 	Parameter Aufgabenmanager
    UNT00 	Texte Nachrichten
    UPA00 	Aktiondefinitionen
    UPD00 	Paneldefinitionen
    UPE00 	Einstellungen
    UPK00 	Parameterübersicht Kopfdaten
    UPL00 	Parameterübersicht Selektion
    UPQ00 	Parameterübersicht SQL-Queri
    UPR00 	Protokolldatei Aufrufdauer
    UPS00 	Sichten, SQL, Select, Input,
    USD00 	SoftM-Basis : Steuerdatei sp
    USP00 	SoftM-Basis : Fremdsprachlic
    UST00 	SoftM Tools : Steuerdatei de
    USX00 	SoftM Suite : Feldinhalte fü
    UTD00 	Temporäre Datei für Prüfdaten
    UTS00 	Nur zum testen
    UVB00 	Berechtigungen Verzweiger na
    UVP00 	Verzweigungen je Programm
    UVS00 	Verzweiger Parameter-Matrix-
    UVZ00 	Verzweiger Parameter-Matrix-
    UWS00 	C/S Arbeitsdatei
    UXD00 	XML: Übertragungs-/Griddefin
    UXM00 	Utitlies Testdatei für Sende
    UZA00 	Feldkatalog für Anzeigeprogr
    UZB00 	Feldkatalog für ausgelagerte
    UZF00 	zentraler Feldkatalog für ze
    UZP00 	Feldkatalog für Prüfinhalte
    UZS00 	Feldkatalog für Prüfinhalte
    UZT00 	Feldkatalog für Texte
    UZV00 	Vergleich/Löschen DOKU (f. A
    UZW00 	Feldkatalog für Dateiwartung

## X - Modulübergreifend ##

    XLB00 	Lagerbewegungen, Aufsummierte Bewegungsdaten / Statistik
    XPN00 	Konditionen Einzelwerte / Konditions-Staffel-Datei
    XPR00 	Preisdatei / Konditionen
    X#B00 	Beispieldatei für XXXXX
    XAA00 	Geänderte Artikelgruppen-Zuo
    XAB00 	SoftM Menü : Abteilungsdatei
    XAC00 	SoftM Menü : Abteilungs-Code
    XAD00 	SoftM Suite : Adressen Aufträge
    XAF00 	Fremdsprachliche Artikelbezeichnungen
    XAG00 	SoftM Suite : Artikelgruppen
    XAR00 	SoftM Suite : Artikelstammdaten
    XAV00 	Artikel-Varianten-Zuordnung
    XAX00 	SoftM Suite : Artikeltexte
    XBA00 	Zwischendatei: für ABC-Analy
    XBC00 	Berechtigungscodedatei
    XBL00 	Bundesländer/Regionen?
    XBO00 	SoftM Suite : Businessobjekt
    XBS00 	BArcode-Schnittstellen-Datei
    XBV00 	7.00 Definition der Nummernk
    XBW00 	7.00 Nummernkreiszähler
    XBX00 	Zuordnugstabelle Klassifizie
    XCB00 	Blockdatei / Ablaufkontrolle
    XCD00 	Empfangsdatei
    XCE00 	Sendedatei
    XCG00 	Chargengrößen je Artikel
    XCH00 	Chargen-Stamm-Datei
    XCK00 	Kontrolldatei / Ablaufkontro
    XCM00 	Chargen-Bestandsdatei
    XCN00 	Datei für Konstanten mit *NO
    XCP00 	Partnerdatei
    XCS00 	Statusdatei / Ablaufkontroll
    XCT00 	Sende- und Empfangstypen
    XCU00 	Chargen-Umsatz-Datei
    XCV00 	Dateianforderung / Ablaufkon
    XCW00 	Protokolldatei
    XCY00 	Protokoll-Datei: Aufrufparam
    XCZ00 	Chargen-Zuordnungsdatei
    XDB00 	7.00 Parameter Nummernverga
    XDK00 	Dateidatei für Formulare
    XDO00 	SoftM Suite : Zuordnung Outq
    XDP00 	SoftM Basis : Dateiwartungsp
    XDQ00 	SoftM Basis : Arbeitsdatei f
    XDR00 	XDR00: Dispositionskennzahle
    XDS00 	Druckertypen mit Druckersteu
    XDT00 	7.00 Parameter Definition D
    XDU00 	XDU00: Umlagerungsdefinition
    XDV00 	SoftM Basis : Verteilerliste
    XDW00 	Übersicht über Dateiwartungs
    XDY00 	SoftM Suite : Steuerdatei fü
    XDZ00 	SoftM Basis : Druckerzuordnu
    XEA00 	Stapelschnittstelle Einkauf
    XEB00 	Emballagen-Bewegungsdatei
    XED00 	SoftM Basis : Intrastat-Date
    XEE00 	SoftM Basis : Intrastat-Date
    XEF00 	Emballagen-Bewegungs-Datei/n
    XEI00 	SoftM Basis : Intrastat-Date
    XEK00 	Emballagen-Konten-Datei
    XEM00 	Umrechnungsfaktoren / INTRAS
    XEP00 	Prozentsätze für Ermittlung
    XES00 	Serien-Nr. Zugang aus Einkau
    XFC00 	SoftM Basis : Firmencode-Dat
    XFI00 	EDIFACT-Eingangsschnittstell
    XFO00 	Formularkonstaten
    XFS00 	Fahrzeugstamm
    XFT00 	SoftM Basis : Fehlertexte
    XFZ00 	Fahrerzusatzdaten
    XGB00 	SoftM Basis : Gebinde-/Verka
    XGE00 	SoftM Suite : Artikel-Gebind
    XGF00 	SoftM Suite : Zuordnung Bear
    XGJ00 	Geschäftsjahre
    XGM00 	SoftM Suite : Bearbeitungsma
    XGO00 	SoftM Suite : Zustand Bearbe
    XGP00 	SoftM Suite : Zuordnung BO-A
    XGT00 	SoftM Suite : Businessobjekt
    XGU00 	SoftM Suite : Update-Regeln
    XGV00 	SoftM Suite : Zuordnung Sach
    XGW00 	SoftM Suite : Where-Bedinung
    XGZ00 	Beschreibung Businessobjekt
    XHE00 	Hierarchiebereiche
    XHR00 	Hierarchiezuordnung
    XHS00 	Hierarchien
    XHZ00 	Stammdatendefinitionen für A
    XIA00 	SoftM Basis : Infostore Ausw
    XIM00 	Bildschirm-Abbilder für Ausk
    XIS00 	Auskunftssystem SoftM BASIS:
    XKD00 	Kundenstammdaten
    XKF00 	Kalender kirchliche/staatlic
    XKL00 	Kalender Datei - Tagesebene
    XKP00 	SoftM Basis : Schlüssel-Prüf
    XKS00 	SoftM Basis : Kundenzusatz (
    XKW00 	Kundenstammzusatz: Warenkred
    XLA00 	SoftM Suite : Länderdatei
    XLF00 	SoftM Lager : Bestandsführun
    XLI00 	SoftM Basis : Lieferanten-Ad
    XLL00 	List & Labels Nachrichtendat
    XLS00 	SoftM Basis : Lieferantenzus
    XLX00 	Kunden- bzw. Lieferanten-Tex
    XLY00 	XYP00: Zuordnung XLB00 zu XY
    XMA00 	Menüdatei für Anzeige
    XMB00 	Befehlsdefintionsdatei
    XME00 	Menüdatei
    XMF00 	Betriebsprüfer Menüzusatz
    XMI00 	SoftM Basis : Mischkontenadr
    XMK00 	Menükopfdatei
    XMP00 	Menü-Protokoll-Datei
    XMX00 	Definfition Maximalbestände
    XNE00 	XNE00: Nachfragestatistik-Da
    XNF00 	Nachfolge-Artikel-Definition
    XNR00 	Nummernkreise
    XNS00 	Aufsummierte NAchfrage / Statistik
    XNS00 	Nachfragestatistik-Datei
    XNV00 	XNV00: Nachfrage- / Verbrauc
    XNW00 	Verbrauchs- und Nachfragedat
    XOI00 	EDI-Schnittstellendatei
    XOO00 	EDIFACT-Schnittstelle für Au
    XPA00 	Protokolldatei für Performan
    XPB00 	Budgetdaten - Kosten
    XPC00 	Neue Konditionsdatei Konditi
    XPD00 	Partneridentifikation
    XPF00 	Pfaddatei
    XPK00 	Listen / Print - Konstanten
    XPV00 	Dokumentenverwaltung
    XPW00 	Neue Preisdatei Suchbaum
    XPX00 	SoftM Suite : Parameterdatei
    XPZ00 	Neue Preisdatei Preiszugriff
    XRA00 	Umbenennen von Artikelnummer
    XRS00 	Ressourcendatei
    XRZ00 	ArbDat? für Verursacher<->Dec
    XSA00 	EDI-Satzarten
    XSB00 	Sachbearbeiter-Datei
    XSC00 	Zusätzliche Berechtigungscod
    XSG00 	Zuordnung Sachbearbeiter zu
    XSL00 	Lager-Stapel-Schnittstelle
    XSN00 	Allgemeine Satznummerndatei
    XSP00 	Protokolldatei: Stammdaten,
    XSU00 	Suchbegriffdatei für Artikel
    XSW00 	Stichwortdatei für Artikel/K
    XTA00 	Transfer-Anforderungen für S
    XTB00 	SoftM Basis : Standardtextda
    XTD00 	Druck-Kennzeichen für AAT00,
    XTE00 	Eingehender Anruf: Zwischens
    XTF00 	Datentransfer: Schnittstelle
    XTK00 	Tageskurse nach FNR,WSL,Datu
    XTP00 	Transfer-Protokoll
    XTQ00 	Protokoll-/Transfersteuerung
    XTV00 	Definitionen für Texteditor
    XTY00 	SoftM Suite : Versandarten
    XUF00 	Umrechnungsfaktoren
    XUS00 	Unterlagenstamm FNR,UTYP,ULN
    XUV00 	Umverpackungen
    XUZ00 	Unterlagenzuordnung
    XV#00 	Hilfsdatei VPreisbildung
    XVG00 	Diverse Kosten
    XVO00 	SoftM Basis : Vorprogrammier
    XVR00 	SoftM Basis : Vertreterstamm
    XVT00 	Texte Umverpackung/Matrix K'
    XVU00 	Zuordnungsdatei Bedarf/Decku
    XVY00 	Verrechnungspreise
    XWA00 	LOGIN Datei für Web
    XWC00 	SoftM Basis : Artikelstamm f
    XWD00 	SoftM Basis : Artikelstamm f
    XWE00 	SoftM Suite: Bezeichnungsdat
    XWF00 	SoftM Suite: Hierarchedatei
    XWH00 	Hierarchie nach Ebene 01 für
    XWL00 	Logdatei für Web
    XWP00 	XWP00: Definition erlaubter
    XWR00 	SoftM Basis: Wiederanlaufdat
    XWS00 	Bildschirm-Arbeitsdatei
    XWT00 	SoftM Basis: Wiederanlaufdat
    XWV00 	Branntweinsteuer: Verbrauchs
    XWZ00 	Branntweinsteuer: Artikelzus
    XXA00 	SoftM Suite : Adressdatei
    XXC00 	SoftM Suite : Stammdaten für
    XXD00 	SoftM Basis : Abfrage-Defini
    XXE00 	Parameter für Etikettendruck
    XXF00 	SoftM Basis: Stammdaten für
    XXG00 	SoftM Basis: Stammdaten Kd./
    XXJ00 	SoftM Basis : Normalisierte
    XXL00 	Kundenartikeldefinition
    XXM00 	SoftM Suite: Kunden aus Vert
    XXO00 	SoftM Suite : Schnittstelle
    XXP00 	SoftM Basis : Ansprechpartne
    XXQ00 	SoftM Suite : Schnittstlle f
    XXS00 	SoftM Suite : Selektionserge
    XXT00 	SoftM Suite : Textdatei für
    XXV00 	Verteilungsschlüsseldatei
    XXZ00 	SoftM Suite : Ansprechpartne
    XY100 	SoftM Suite : Übergabedatei
    XYB00 	Zuordnung Artikel/KLasse
    XYE00 	Ergebnistabelle II
    XYG00 	AQL-Tabelle
    XYI00 	Q-Daten Kopf IST/Prüfauftrag
    XYJ00 	Q-Daten Positionen IST/Prüfa
    XYK00 	Materialklassen - Kopfinfos
    XYL00 	Materialklassen - Positionen
    XYM00 	Sach-/Qualitätsmerkmale
    XYP00 	XYP00: Anforderungsprofiltex
    XYS00 	Merkmalsleiste für eine Zuor
    XYT00 	Prüftabellen NUM/ALFA
    XYU00 	Quellendatei zu Merkmalsleis
    XYV00 	Klassifizierungsauswahlen
    XYX00 	Ergebnistabelle 1
    XZK00 	Zuordnungsmatrix Kostenarten
    XZV00 	VESR Stammdaten
    XZW00 	VESR Artenstamm